==> spip_3.0.18.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'alerte_confirmer_suppression_signatures' => 'Emaoc’h o vont da ziverkañ an holl sinadegoù. Daoust hag oc’h sur da vont pelloc’h ?',
	'aucune_signature' => 'Sinadur ebet',

	// B
	'bouton_checkbox_envoi_message' => 'Tu ’zo da gas ur gemenadenn',
	'bouton_checkbox_indiquer_site' => 'Ret eo lakaat ul lec’hienn web',
	'bouton_checkbox_signature_unique_email' => 'nemet ur sinadur evit pep chomlec’h postel',
	'bouton_checkbox_signature_unique_site' => 'nemet ur sinadur evit pep lec’hienn web',
	'bouton_radio_activer_petition' => 'Enaouiñ ar sinadeg',
	'bouton_radio_pas_petition' => 'Sinadeg ebet',
	'bouton_radio_petition_activee' => 'Sinadeg war-enaou',
	'bouton_radio_supprimer_petition' => 'Dilemel ar sinadeg',

	// F
	'filtre' => 'Sil : ',
	'form_pet_adresse_site' => 'Chomlec’h ho lec’hienn', # MODIF
	'form_pet_aucune_signature' => 'Sinadur ebet ne glot gant ar c’hod-mañ...', # MODIF
	'form_pet_confirmation' => 'Kadarnait ho sinadur mar-plij :',
	'form_pet_deja_signe' => 'Sinet eo bet an destenn-se ganeoc’h c’hoazh.',
	'form_pet_envoi_mail_confirmation' => 'Emeur o paouez kas ur postel gwiriañ da @email@. Ret e vo deoc’h gweladenniñ ar chomlec’h meneget er postel-se a-benn kadarnaat ho sinadur.', # MODIF
	'form_pet_mail_confirmation' => 'Demat, 

Goulennet hoc’h eus sinañ ar sinadeg :
@titre@.

An titouroù-mañ zo bet roet ganeoc’h :
    Anv: @nom_email@
    Lec’hienn: @nom_site@ - @url_site@
@message@

POUEZUS...
Evit kadarnaat ho sinadur eo trawalc’h deoc’h mont d’ar chomlec’h amañ dindan
(ma ne rit ket se, ne vo ket ouzhpennet ho sinadur) :

    @url@


Trugarez da gemer perzh
',
	'form_pet_message_commentaire' => 'Ur gemenadenn, un addisplegadenn ?',
	'form_pet_nom_site2' => 'Anv ho lec’hienn', # MODIF
	'form_pet_probleme_liens' => 'Savit ho kemennadenn en-dro en ur dennañ ar gourliammoù zo enni. ',
	'form_pet_probleme_technique' => 'Ur gudenn deknikel zo, n’haller ket sinañ evit ar poent.',
	'form_pet_signature_validee' => 'Kadarnaet eo bet ho sinadur. Trugarez !',
	'form_pet_site_deja_enregistre' => 'Enrollet eo bet al lec’hienn-mañ c’hoazh',
	'form_pet_url_invalide' => 'Direizh eo an URL bet merket ganeoc’h.',
	'form_pet_votre_email' => 'Ho chomlec’h postel',
	'form_pet_votre_nom' => 'Hoc’h anv pe lesanv', # MODIF
	'form_pet_votre_site' => 'M’ho peus ul lec’hienn Web e c’hellit he mennegiñ amañ da-heul',

	// I
	'icone_relancer_signataire' => 'Adlañsañ ar sinader.',
	'icone_relancer_signataires' => 'Alañsañ  ar sinaderien',
	'icone_suivi_petitions' => 'Heuliañ/merañ ar sinadegoù',
	'icone_supprimer_signature' => 'Diverkañ ar sinadur mañ',
	'icone_supprimer_signatures' => 'Diverkañ ar sinadurioù',
	'icone_valider_signature' => 'Gwiriekaat ar sinadur mañ',
	'icone_valider_signatures' => 'Gwirekaat ar sinadurioù',
	'info_adresse_email' => 'POSTEL :',
	'info_fonctionnement_petition' => 'Mont en-dro ar sinadeg :',
	'info_signature_supprimee' => 'Diverket eo bet ar sinadur',
	'info_signature_supprimee_erreur' => 'Fazi : ne glot ar c’hod diverkañ-mañ gant sinadur ebet.', # MODIF
	'info_site_web' => 'LEC’HIENN :',
	'info_texte_message' => 'Testenn ho kemenadenn :',

	// L
	'lien_reponse_article' => 'Respont d’ar pennad',

	// S
	'sans_nom' => 'Dizanv',
	'signatures_article' => 'Sinadurioù ar pennadoù-skrid',
	'signatures_aucune' => 'Hini ebet',
	'signatures_meme_auteur' => 'Sinadurioù ar memes aozour',
	'signatures_meme_site' => 'Sinadurioù ar memes lec’hienn',
	'signatures_poubelle' => 'Bet dilemet',
	'signatures_prop' => 'Lakaet da c’hortoz',
	'signatures_publie' => 'Bet kadarnaet',
	'signatures_recherche_label' => 'Klask sinadurioù : ',
	'signatures_selection' => 'Diuzañ ar sinadurioù : ',
	'signatures_toutes' => 'An holl',
	'statut_poubelle' => 'Bet dilemet',
	'statut_prop' => 'O c’hortoz da vezañ kadarnaet',
	'statut_publie' => 'Ber kadarnaet',

	// T
	'texte_descriptif_petition' => ' Deskrivadur ar sinadeg',
	'titre_page_controle_petition' => 'Heuliañ ar sinadegoù',
	'titre_petition' => 'Sinadeg',
	'titre_selection_action' => 'Diuz',
	'titre_signatures_attente' => 'Sinadurioù o c’hortoz bezañ gwiriedekaet',
	'titre_signatures_publie' => 'Sinadurioù gwiriedekaet',
	'titre_suivi_petition' => 'Heuliañ ar sinadegoù',
	'tout_voir' => 'Gwelet an holl sinadurioù',

	// U
	'une_signature' => '1 sinadur',

	// V
	'voir_signatures_objet' => 'Gwelet ar sinadurioù'
);

?>

==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// F
	'form_pet_adresse_site' => 'Chomlec’h ho lec’hienn', # MODIF
	'form_pet_aucune_signature' => 'Sinadur ebet ne glot gant ar c’hod-mañ...', # MODIF
	'form_pet_confirmation' => 'Kadarnait ho sinadur mar-plij :',
	'form_pet_deja_signe' => 'Sinet eo bet an destenn-se ganeoc’h c’hoazh.',
	'form_pet_envoi_mail_confirmation' => 'Emeur o paouez kas ur postel gwiriañ da @email@. Ret e vo deoc’h gweladenniñ ar chomlec’h meneget er postel-se a-benn kadarnaat ho sinadur.', # MODIF
	'form_pet_mail_confirmation' => 'Demat, 

Goulennet hoc’h eus sinañ ar sinadeg :
@titre@.

An titouroù-mañ zo bet roet ganeoc’h :
    Anv: @nom_email@
    Lec’hienn: @nom_site@ - @url_site@
@message@

POUEZUS...
Evit kadarnaat ho sinadur eo trawalc’h deoc’h mont d’ar chomlec’h amañ dindan
(ma ne rit ket se, ne vo ket ouzhpennet ho sinadur) :

    @url@


Trugarez da gemer perzh
',
	'form_pet_nom_site2' => 'Anv ho lec’hienn', # MODIF
	'form_pet_probleme_liens' => 'Savit ho kemennadenn en-dro en ur dennañ ar gourliammoù zo enni. ',
	'form_pet_probleme_technique' => 'Ur gudenn deknikel zo, n’haller ket sinañ evit ar poent.',
	'form_pet_signature_validee' => 'Kadarnet eo bet ho sinadur. Trugarez !',
	'form_pet_site_deja_enregistre' => 'Enrollet eo bet al lec’hienn-mañ c’hoazh',
	'form_pet_url_invalide' => 'Direizh eo an URL bet merket ganeoc’h.',
	'form_pet_votre_email' => 'Ho chomlec’h postel',
	'form_pet_votre_nom' => 'Hoc’h anv pe lesanv', # MODIF
	'form_pet_votre_site' => 'M’ho peus ul lec’hienn Web e c’hellit he mennegiñ amañ da-heul',

	// I
	'info_adresse_email' => 'POSTEL :',
	'info_signature_supprimee' => 'Diverket eo bet ar sinadur',
	'info_signature_supprimee_erreur' => 'Fazi : ne glot ar c’hod diverkañ-mañ gant sinadur ebet.', # MODIF
	'info_site_web' => 'LEC’HIENN :',

	// L
	'lien_reponse_article' => 'Respont d’ar pennad'
);

?>
